# Command Line
The Sonolus.py CLI provides commands to run and build Sonolus scripts.

## Starting a development server
To start a development server, run the following command in the root directory of your project:

```bash
sonolus-py dev
```

## Building the project
To build the project, run the following command in the root directory of your project:

```bash
sonolus-py build
```

## Checking for errors without building
To check for errors, run the following command in the root directory of your project:

```bash
sonolus-py check
```

## Outputting the level schema
To output the level schema of the project, run the following command in the root directory of your project:

```bash
sonolus-py schema
```

## Programmatic usage
The same functionality can be accessed programmatically as methods of a project.

See [Project](../reference/sonolus.script.project.md) for more information.
